<?php
/*
Plugin Name: Auto Tagging Plugin
Description: Automatically updates tags for posts that have no tags and fills them with the post title.
Version: 1.0
Author: Your Name
*/

// Add an admin menu for the settings page
function atp_add_admin_menu() {
    add_menu_page(
        'Auto Tagging', // Page title
        'Auto Tagging', // Menu title
        'manage_options', // Required capability
        'auto-tagging', // Menu slug
        'atp_settings_page', // Function to display content
        'dashicons-tag', // Icon
        100 // Menu position
    );
}
add_action('admin_menu', 'atp_add_admin_menu');

// Function to display the settings page
function atp_settings_page() {
    ?>
    <div class="wrap">
        <h1>Auto Tagging Settings</h1>
        <p>The Auto Tagging plugin automatically updates tags for posts that have no tags, filling them with the post title.</p>

        <h2>Installation Instructions</h2>
        <p>Follow these steps to install the plugin:</p>
        <ol>
            <li>Go to the <code>wp-content/plugins/</code> folder in your WordPress installation directory.</li>
            <li>Create a new folder named <code>auto-tagging-plugin</code>.</li>
            <li>Inside this folder, create a new file named <code>auto-tagging-plugin.php</code> and paste the provided code inside.</li>
            <li>Go to the WordPress admin panel and navigate to the <strong>Plugins</strong> section. Activate the <strong>Auto Tagging Plugin</strong>.</li>
        </ol>

        <h2>Settings</h2>
        <p>On this page, you can manage the automatic tag update or run the manual update process.</p>
        
        <!-- Button to trigger the update process -->
        <form method="post" action="">
            <input type="submit" name="atp_run" class="button-primary" value="Run Tag Update">
        </form>
        
        <hr>

        <h2>Advanced Settings (Optional)</h2>
        <p>If you want to schedule an automatic tag update once a week, you can enable the following option:</p>
        <form method="post" action="">
            <p>
                <label for="atp_schedule_update">
                    <input type="checkbox" name="atp_schedule_update" id="atp_schedule_update" <?php checked(get_option('atp_schedule_update'), 'on'); ?>>
                    Schedule automatic tag updates weekly
                </label>
            </p>
            <p><input type="submit" name="atp_save_settings" class="button-primary" value="Save Settings"></p>
        </form>

        <hr>
        
        <h2>Notes</h2>
        <p>This plugin is helpful if you have a large number of posts that lack tags. Once the automatic update is enabled, tags will be added automatically using the post title.</p>
        <p>You can also manually run the update process by clicking the button above to update all posts right away.</p>
        <p>If you need to customize the tags or add additional features, you can modify the code directly in the plugin file.</p>
        
    </div>
    <?php
    // If the "Run Tag Update" button is clicked
    if (isset($_POST['atp_run'])) {
        atp_auto_update_tags();
        echo '<div class="updated"><p>Tags have been successfully updated!</p></div>';
    }

    // If the settings are saved
    if (isset($_POST['atp_save_settings'])) {
        $schedule_update = isset($_POST['atp_schedule_update']) ? 'on' : '';
        update_option('atp_schedule_update', $schedule_update);
        echo '<div class="updated"><p>Settings have been saved successfully!</p></div>';
    }
}

// Function to update tags for all posts
function atp_auto_update_tags() {
    $args = array(
        'posts_per_page' => -1,  // Get all posts
        'post_type' => 'post',   // Post type is 'post'
        'post_status' => 'publish'  // Only published posts
    );
    $posts = get_posts($args);

    foreach ($posts as $post) {
        $tags = get_the_tags($post->ID);
        
        // If no tags are set
        if (!$tags) {
            // Set the post title as the tag
            $new_tags = wp_set_post_tags($post->ID, $post->post_title);
        }
    }
}

// Function to schedule automatic update of tags
function atp_schedule_auto_update() {
    if (get_option('atp_schedule_update') === 'on') {
        if (!wp_next_scheduled('atp_auto_update_tags_cron')) {
            wp_schedule_event(time(), 'weekly', 'atp_auto_update_tags_cron');
        }
    } else {
        wp_clear_scheduled_hook('atp_auto_update_tags_cron');
    }
}
add_action('wp', 'atp_schedule_auto_update');

// Function to update tags when cron job is triggered
function atp_cron_update_tags() {
    atp_auto_update_tags();
}
add_action('atp_auto_update_tags_cron', 'atp_cron_update_tags');
?>
