<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>Secure File Upload Form | Upload Files Safely</title>
    <meta name="description" content="Upload your files securely with our file upload form. Supports JPG, PNG, PDF, and ZIP files. Fast, safe, and easy to use.">
    <meta name="keywords" content="file upload, secure upload, upload files, JPG, PNG, PDF, ZIP, safe file upload">
    <meta name="author" content="Mbsmgroup">
    <meta name="robots" content="index, follow">
    <link rel="canonical" href="https://www.mbsm.tn/upload">
    <link rel="stylesheet" href="style.css">

    <style>
        .message-box {
            margin-top: 20px;
            padding: 10px;
            border: 1px solid #ccc;
            background-color: #f9f9f9;
            color: #333;
            text-align: center;
            max-width: 500px;
            margin-left: auto;
            margin-right: auto;
        }
        .error-message {
            color: red;
        }
        .success-message {
            color: green;
        }
        .refresh-button {
            margin-top: 20px;
            padding: 10px 20px;
            background-color: #f44336;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 16px;
        }
        .refresh-button:hover {
            background-color: #d32f2f;
        }
    </style>
</head>
<body>

<div class="upload-container">
    <img src="images/mbsm.png" alt="MBSM Logo - Secure File Upload Service" width="150">
    <h1>Secure File Upload</h1>

    <br>
    <button onclick="window.location.href='https://mbsm.tn/upload/help.html'">Help</button>
    <button onclick="window.open('https://mbsm.tn/', '')">Mbsm.tn</button>
    <button onclick="window.open('https://mbsm.pro/', '')">Mbsm.pro</button>
    <button onclick="window.open('https://mbsm.tn/upload/file-list.php', '')">List</button>
    <br>

    <form action="" method="post" enctype="multipart/form-data">
        <input type="file" name="filesToUpload[]" id="filesToUpload" multiple required>

        <!-- Captcha Field: Simple Question -->
        <label for="captcha">What is 1 + 0 =  </label>
        <input type="text" id="captcha" name="captcha" maxlength="2" size="2" required>

        <input type="submit" value="Upload Files" name="submit">
    </form>

    <button onclick="hardRefresh()" class="refresh-button">Refresh</button>

    <div class="message-box">
        <?php
        session_start(); // Start the session

        if (isset($_GET['refresh'])) {
            session_unset(); // Clear session variables
            session_destroy(); // Destroy the session
        }

        // Handle file upload logic here
        if (isset($_POST['submit'])) {
            // Captcha verification
            if ($_POST['captcha'] != '1') {
                echo "<p class='error-message'>Error: Incorrect answer to the captcha question.</p>";
            } else {
                // Configuration
                $target_dir = "uploads/";
                $max_file_size = 10 * 1024 * 1024; // 10MB
                $allowed_types = ['image/jpeg', 'image/png', 'application/pdf', 'application/zip'];

                // Check if the "uploads" directory exists, create it if not
                if (!is_dir($target_dir)) {
                    mkdir($target_dir, 0755, true);
                }

                // Process each file
                foreach ($_FILES['filesToUpload']['name'] as $key => $file_name) {
                    $file_name = "Mbsm-tn-media-" . basename($file_name);
                    $file_name = preg_replace('/[^a-zA-Z0-9\.\-_]/', '-', $file_name);
                    $file_name = preg_replace('/-+/', '-', $file_name);
                    $file_extension = pathinfo($file_name, PATHINFO_EXTENSION);
                    $base_name = pathinfo($file_name, PATHINFO_FILENAME);
                    $unique_file_name = $base_name . '.' . $file_extension;
                    $counter = 1;

                    while (file_exists($target_dir . $unique_file_name)) {
                        $unique_file_name = $base_name . '-' . $counter . '.' . $file_extension;
                        $counter++;
                    }

                    $target_file = $target_dir . $unique_file_name;

                    // MIME type
                    $finfo = finfo_open(FILEINFO_MIME_TYPE);
                    $file_mime_type = finfo_file($finfo, $_FILES['filesToUpload']['tmp_name'][$key]);
                    finfo_close($finfo);

                    if ($_FILES["filesToUpload"]["name"][$key] != "") {
                        if (!in_array($file_mime_type, $allowed_types)) {
                            echo "<p class='error-message'>Error: Only JPG, PNG, PDF, and ZIP files are allowed.</p>";
                        } elseif ($_FILES['filesToUpload']['size'][$key] > $max_file_size) {
                            echo "<p class='error-message'>Error: File size exceeds the maximum limit of 10MB.</p>";
                        } else {
                            if (move_uploaded_file($_FILES["filesToUpload"]["tmp_name"][$key], $target_file)) {
                                echo "<p class='success-message'>File uploaded successfully: <a href='$target_file' target='_blank'>Open file in a new window</a></p>";
                                echo "<br><strong>File Information:</strong><br>";
                                echo "File Name: " . htmlspecialchars($file_name) . "<br>";
                                echo "File Type: " . htmlspecialchars($file_mime_type) . "<br>";
                                echo "File Size: " . round($_FILES['filesToUpload']['size'][$key] / 1024, 2) . " KB<br>";
                                echo "File Extension: " . htmlspecialchars($file_extension) . "<br>";
                            } else {
                                echo "<p class='error-message'>Error while uploading the file.</p>";
                            }
                        }
                    } else {
                        echo "<p class='error-message'>No file selected.</p>";
                    }
                }
            }
        }
        ?>
    </div>
</div>

<script>
    function hardRefresh() {
        document.cookie.split(";").forEach(function(cookie) {
            const [name] = cookie.split("=");
            document.cookie = name + "=; expires=Thu, 01 Jan 1970 00:00:00 UTC; path=/;";
        });
        window.location.href = window.location.pathname + '?refresh=true';
    }
</script>

</body>
</html>
