<?php
// Enable error reporting for easier debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Path to the directory containing the files
$uploadDirectory = "/home/mbsmprokiz/mbsm.tn/upload/uploads/"; // Replace with the correct path
$rootDirectory = "/home/mbsmprokiz/mbsm.tn/upload/sitemap/"; // Directory to save the generated files

// Create the sitemap directory if it doesn't exist
if (!file_exists($rootDirectory)) {
    mkdir($rootDirectory, 0755, true);
}

// Get the list of files from the directory
$files = scandir($uploadDirectory);

// Filter out "." and ".." from the list
$files = array_diff($files, array('.', '..'));

// Limit the number of files to 1000
$files = array_slice($files, 0, 1000);

// Create content for sitemap.xml
$xmlContent = '<?xml version="1.0" encoding="UTF-8"?>
<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">';

// Create content for sitemap.html
$htmlContent = '<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Sitemap</title>
</head>
<body>
    <h1>File Links</h1>
    <ul>';

// Create content for sitemap.txt
$txtContent = '';

foreach ($files as $file) {
    $filePath = $uploadDirectory . $file;
    $fileUrl = "https://mbsm.tn/upload/uploads/" . $file; // Public URL of the file

    // Add to sitemap.xml (without <lastmod>)
    $xmlContent .= '
    <url>
        <loc>' . $fileUrl . '</loc>
    </url>';

    // Add to sitemap.html
    $htmlContent .= '
    <li><a href="' . $fileUrl . '" target="_blank">' . $file . '</a></li>';

    // Add to sitemap.txt
    $txtContent .= $fileUrl . PHP_EOL;
}

// Close sitemap.xml content
$xmlContent .= '
</urlset>';

// Close sitemap.html content
$htmlContent .= '
    </ul>
</body>
</html>';

// Save sitemap.xml
file_put_contents($rootDirectory . 'sitemap.xml', $xmlContent);

// Save sitemap.html
file_put_contents($rootDirectory . 'sitemap.html', $htmlContent);

// Save sitemap.txt
file_put_contents($rootDirectory . 'sitemap.txt', $txtContent);

// Create PDF file using TCPDF library
require_once(__DIR__ . '/tcpdf/tcpdf.php'); // Ensure TCPDF is installed correctly
$pdf = new TCPDF();
$pdf->AddPage();
$pdf->SetFont('helvetica', '', 12);
$pdf->WriteHTML($htmlContent); // Use HTML content to create PDF
$pdf->Output($rootDirectory . 'sitemap.pdf', 'F');

// List of generated files
$generatedFiles = [
    'sitemap.xml',
    'sitemap.html',
    'sitemap.txt',
    'sitemap.pdf'
];

// Create a table to display the generated files
$tableContent = '<table border="1" style="margin: auto; text-align: center; width: 50%;">
    <tr>
        <th>File Name</th>
        <th>Link</th>
    </tr>';

foreach ($generatedFiles as $file) {
    $fileUrl = "https://mbsm.tn/upload/sitemap/" . $file; // Public URL of the file

    // Add to the table
    $tableContent .= '
    <tr>
        <td>' . $file . '</td>
        <td><a href="' . $fileUrl . '" target="_blank">Open File</a></td>
    </tr>';
}

// Close the table content
$tableContent .= '
</table>';

// Display the logo and buttons
echo '<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Generated Files</title>
    <style>
        table {
            margin: 20px auto;
            border-collapse: collapse;
            width: 50%;
        }
        th, td {
            padding: 10px;
            border: 1px solid #000;
        }
        th {
            background-color: #f2f2f2;
        }
        a {
            text-decoration: none;
            color: #007BFF;
        }
        a:hover {
            text-decoration: underline;
        }
        .logo-container {
            text-align: center;
            margin-top: 20px;
        }
        .button-container {
            text-align: center;
            margin: 20px 0;
        }
        .button-container button {
            margin: 5px;
            padding: 10px 20px;
            font-size: 16px;
            cursor: pointer;
            border: none;
            background-color: #007BFF;
            color: white;
            border-radius: 5px;
        }
        .button-container button:hover {
            background-color: #0056b3;
        }
    </style>
</head>
<body>
    <!-- Add logo at the top -->
    <div class="logo-container">
        <img src="https://mbsm.tn/upload/images/mbsm.png" alt="MBSM Logo - Secure File Upload Service" width="150">
    </div>

    <!-- Add buttons below the logo -->
    <div class="button-container">
        <button onclick="window.location.href=\'https://mbsm.tn/upload/help.html\'">Help</button>
        <button onclick="window.location.href=\'https://mbsm.tn/upload/\'">Upload</button>
        <button onclick="window.open(\'https://mbsm.tn/\', \'_blank\')">Mbsm.tn</button>
        <button onclick="window.open(\'https://mbsm.pro/\', \'_blank\')">Mbsm.pro</button>
        <button onclick="window.open(\'https://mbsm.tn/upload/sitemap.php/\', \'_blank\')">Sitemap</button>
    </div>

    <h1 style="text-align: center;">Generated Files</h1>
    ' . $tableContent . '
</body>
</html>';
?>